Class: Dir

Inherits:
Object
  • Object
show all
Defined in:
lib/safegem/security.rb

Overview

Bug in ruby doesn’t check taint when an array of globs is passed

Constant Summary collapse

@@safe_level =

we need to track $SAFE level manually because define_method captures the $SAFE level of the current scope, as it would a local varaible, and of course the current scope has a $SAFE of 0

0

Class Method Summary collapse

Class Method Details

.set_safe_levelObject

since this method is defined with def instead of define_method, $SAFE will be taken from the calling scope which is what we want



57
58
59
# File 'lib/safegem/security.rb', line 57

def set_safe_level
  @@safe_level = $SAFE
end